==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebTabPanelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabPanelDescription } from "./WebTabPanelDescription";
/**
 * @hidden
 */
var WebTabPanelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabPanelDescriptionMetadata, _super);
    function WebTabPanelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabPanelDescriptionMetadata.b = function (a) {
        if (WebTabPanelDescriptionMetadata.a == null) {
            WebTabPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabPanelDescriptionMetadata.c(WebTabPanelDescriptionMetadata.a);
        }
        if (a.g(WebTabPanelDescriptionMetadata.a)) {
            return;
        }
        a.s(WebTabPanelDescriptionMetadata.a);
    };
    WebTabPanelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabPanel");
    };
    WebTabPanelDescriptionMetadata.d = function (a) {
        WebTabPanelDescriptionMetadata.b(a);
        a.u("WebTabPanel", function () { return new WebTabPanelDescription(); });
        a.t("WebTabPanel", WebTabPanelDescriptionMetadata.a);
    };
    WebTabPanelDescriptionMetadata.$t = markType(WebTabPanelDescriptionMetadata, 'WebTabPanelDescriptionMetadata');
    WebTabPanelDescriptionMetadata.a = null;
    return WebTabPanelDescriptionMetadata;
}(Base));
export { WebTabPanelDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebTabPanelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabPanelDescription } from "./WebTabPanelDescription";
/**
 * @hidden
 */
var WebTabPanelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabPanelDescriptionMetadata, _super);
    function WebTabPanelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabPanelDescriptionMetadata.b = function (a) {
        if (WebTabPanelDescriptionMetadata.a == null) {
            WebTabPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabPanelDescriptionMetadata.c(WebTabPanelDescriptionMetadata.a);
        }
        if (a.j(WebTabPanelDescriptionMetadata.a)) {
            return;
        }
        a.y(WebTabPanelDescriptionMetadata.a);
    };
    WebTabPanelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabPanel");
        a.item("__tagNameWC", "String:igc-tab-panel");
    };
    WebTabPanelDescriptionMetadata.d = function (a) {
        WebTabPanelDescriptionMetadata.b(a);
        a.aa("WebTabPanel", function () { return new WebTabPanelDescription(); });
        a.z("WebTabPanel", WebTabPanelDescriptionMetadata.a);
    };
    WebTabPanelDescriptionMetadata.$t = markType(WebTabPanelDescriptionMetadata, 'WebTabPanelDescriptionMetadata');
    WebTabPanelDescriptionMetadata.a = null;
    return WebTabPanelDescriptionMetadata;
}(Base));
export { WebTabPanelDescriptionMetadata };
